#
# spec file for package gap
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap
Version:        4.14.0
Release:        1.1
Summary:        System for Computational Discrete Algebra
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-system.org/

Source:         https://github.com/gap-system/gap/releases/download/v%version/gap-%version-core.tar.gz
Source2:        macros.gap
Source3:        %name-rpmlintrc
BuildRequires:  gcc-c++
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  readline-devel
BuildRequires:  unzip
BuildRequires:  zlib-devel
Provides:       gap-core = %version-%release
Requires:       gap-gapdoc >= 1.2
Requires:       gap-primgrp >= 3.4.3
Requires:       gap-smallgrp >= 1.5.1
Requires:       gap-transgrp >= 3.6.3

%define lname libgap9
%global gap_sitearch %_libdir/gap/pkg
%global gap_sitelib  %_datadir/gap/pkg

%description
GAP is a system for computational discrete algebra, with particular
emphasis on Computational Group Theory. GAP provides a programming
language, a library of thousands of functions implementing algebraic
algorithms written in the GAP language as well as large data
libraries of algebraic objects. GAP is used in research and teaching
for studying groups and their representations, rings, vector spaces,
algebras, combinatorial structures, and more.

%package -n %lname
Summary:        Kernel for the GAP computation algebra system
Group:          System/Libraries

%description -n %lname
This package contains the GAP kernel in a C library that can be
linked to.

%package devel
Summary:        Development environment for GAP
Group:          Development/Tools/Other
Requires:       %lname = %version

%description devel
GAP is a system for computational discrete algebra, with particular
emphasis on Computational Group Theory.

This package will pull in the current version of the GAP compiler
"gac", as well as utilities required to build GAP packages that need
compilation.

%package rpm-devel
Summary:        RPM macros for building GAP packages
# Not noarch: contains arch-specific paths in RPM macros
Group:          Development/Tools/Other

%description rpm-devel
GAP is a system for computational discrete algebra, with particular
emphasis on Computational Group Theory.

This subpackage provides RPM macros for building GAP modules as RPMs.

%package full
Summary:        Metapackage to cause installation of the GAP Distribution
Group:          Metapackages
BuildArch:      noarch
Requires:       gap >= %version
Requires:       gap-4ti2interface >= 2024.11.01
Requires:       gap-ace >= 5.6.2
Requires:       gap-aclib >= 1.3.2
Requires:       gap-agt >= 0.3.1
Requires:       gap-alnuth >= 3.2.1
Requires:       gap-anupq >= 3.3.1
Requires:       gap-atlasrep >= 2.1.9
Requires:       gap-autodoc >= 2023.06.19
Requires:       gap-automata >= 1.16
Requires:       gap-automgrp >= 1.3.2
Requires:       gap-autpgrp >= 1.11
Requires:       gap-browse >= 1.8.21
Requires:       gap-cap >= 2024.11.02
Requires:       gap-caratinterface >= 2.3.7
Requires:       gap-cddinterface >= 2024.09.02
Requires:       gap-circle >= 1.6.6
Requires:       gap-classicpres >= 1.22
Requires:       gap-cohomolo >= 1.6.11
Requires:       gap-congruence >= 1.2.7
Requires:       gap-corefreesub >= 0.6
Requires:       gap-corelg >= 1.57
Requires:       gap-crime >= 1.6
Requires:       gap-crisp >= 1.4.6
Requires:       gap-crypting >= 0.10.5
Requires:       gap-cryst >= 4.1.27
Requires:       gap-crystcat >= 1.1.10
Requires:       gap-ctbllib >= 1.3.9
Requires:       gap-cubefree >= 1.20
Requires:       gap-curlinterface >= 2.4.0
Requires:       gap-cvec >= 2.8.2
Requires:       gap-datastructures >= 0.3.1
Requires:       gap-deepthought >= 1.0.7
Requires:       gap-design >= 1.8.2
Requires:       gap-difsets >= 2.3.1
Requires:       gap-digraphs >= 1.9.0
Requires:       gap-edim >= 1.3.8
Requires:       gap-example >= 4.4.0
Requires:       gap-examplesforhomalg >= 2023.10.01
Requires:       gap-factint >= 1.6.3
Requires:       gap-ferret >= 1.0.14
Requires:       gap-fga >= 1.5.0
Requires:       gap-fining >= 1.5.6
Requires:       gap-float >= 1.0.5
Requires:       gap-format >= 1.4.4
Requires:       gap-forms >= 1.2.12
Requires:       gap-fplsa >= 1.2.6
Requires:       gap-fr >= 2.4.13
#dependson jupyterkernel#Requires:       gap-francy >= 2.0.3
Requires:       gap-fwtree >= 1.3
Requires:       gap-gapdoc >= 1.6.7
Requires:       gap-gauss >= 2024.11.01
Requires:       gap-gaussforhomalg >= 2024.08.01
Requires:       gap-gbnp >= 1.1.0
Requires:       gap-generalizedmorphismsforcap >= 2024.09.03
Requires:       gap-genss >= 1.6.9
Requires:       gap-gradedmodules >= 2024.01.01
Requires:       gap-gradedringforhomalg >= 2024.07.01
Requires:       gap-grape >= 4.9.2
Requires:       gap-groupoids >= 1.76
Requires:       gap-grpconst >= 2.6.5
Requires:       gap-guarana >= 0.96.3
Requires:       gap-guava >= 3.19
Requires:       gap-hap >= 1.66
Requires:       gap-hapcryst >= 0.1.15
Requires:       gap-hecke >= 1.5.4
Requires:       gap-help >= 4.0
Requires:       gap-homalg >= 2024.01.01
Requires:       gap-homalgtocas >= 2023.11.01
Requires:       gap-idrel >= 2.48
Requires:       gap-images >= 1.3.3
Requires:       gap-intpic >= 0.4.0
Requires:       gap-io >= 4.9.1
Requires:       gap-io_forhomalg >= 2023.02.04
Requires:       gap-irredsol >= 1.4.4
Requires:       gap-itc >= 1.5.1
Requires:       gap-json >= 2.2.2
#notready#Requires: gap-jupyterkernel >= 1.5.1
#notready#Requires: gap-jupyterviz >= 1.5.6
Requires:       gap-kan >= 1.37
Requires:       gap-kbmag >= 1.5.11
Requires:       gap-laguna >= 3.9.7
Requires:       gap-liealgdb >= 2.2.1
Requires:       gap-liepring >= 2.9.1
Requires:       gap-liering >= 2.4.2
Requires:       gap-linearalgebraforcap >= 2024.10.01
Requires:       gap-lins >= 0.9
Requires:       gap-localizeringforhomalg >= 2023.10.01
Requires:       gap-loops >= 3.4.4
Requires:       gap-lpres >= 1.1.1
Requires:       gap-majoranaalgebras >= 1.5.2
Requires:       gap-mapclass >= 1.4.6
Requires:       gap-matgrp >= 0.71
Requires:       gap-matricesforhomalg >= 2024.11.02
Requires:       gap-modisom >= 3.0.0
# gap-modulepresentationsforcap requires a non-existent gap-complexesandfilteredobjectsforgap
#Requires:      gap-modulepresentationsforcap >= 2024.09.02
Requires:       gap-modules >= 2024.01.01
Requires:       gap-monoidalcategories >= 2024.09.05
Requires:       gap-nconvex >= 2022.09.01
Requires:       gap-nilmat >= 1.4.2
Requires:       gap-nock >= 1.5
Requires:       gap-normalizinterface >= 1.3.7
Requires:       gap-nq >= 2.5.11
Requires:       gap-numericalsgps >= 1.4.0
Requires:       gap-openmath >= 11.5.3
Requires:       gap-orb >= 4.9.1
#we have rpm#Requires:       gap-packagemanager >= 1.6
#Needs separate gap-core built with openmpi and update-alternatives
#Requires:      gap-pargap >= 1.4.3
Requires:       gap-patternclass >= 2.4.5
Requires:       gap-permut >= 2.0.5
Requires:       gap-polenta >= 1.3.10
Requires:       gap-polycyclic >= 2.16
Requires:       gap-polymaking >= 0.8.7
Requires:       gap-primgrp >= 3.4.4
Requires:       gap-profiling >= 2.6.0
Requires:       gap-qpa >= 1.35
Requires:       gap-quagroup >= 1.8.4
Requires:       gap-radiroot >= 2.9
Requires:       gap-rcwa >= 4.7.1
Requires:       gap-rds >= 1.8
Requires:       gap-recog >= 1.4.3
Requires:       gap-repndecomp >= 1.3.0
Requires:       gap-repsn >= 3.1.2
Requires:       gap-resclasses >= 4.7.3
Requires:       gap-ringsforhomalg >= 2024.11.02
Requires:       gap-sco >= 2023.08.01
Requires:       gap-scscp >= 2.4.3
Requires:       gap-semigroups >= 5.4.0
Requires:       gap-sglppow >= 2.4
Requires:       gap-sgpviz >= 0.999.6
Requires:       gap-simpcomp >= 2.1.14
Requires:       gap-singular >= 2024.06.03
Requires:       gap-sl2reps >= 1.1
Requires:       gap-smallantimagmas >= 0.2.12
Requires:       gap-sla >= 1.6.2
Requires:       gap-smallgrp >= 1.5.4
Requires:       gap-smallsemi >= 0.7.1
Requires:       gap-sonata >= 2.9.6
Requires:       gap-sophus >= 1.27
Requires:       gap-spinsym >= 1.5.2
Requires:       gap-standardff >= 1.0
Requires:       gap-symbcompcc >= 1.3.2
Requires:       gap-thelma >= 1.3
Requires:       gap-tomlib >= 1.2.11
Requires:       gap-toolsforhomalg >= 2024.09.01
Requires:       gap-toric >= 1.9.6
Requires:       gap-toricvarieties >= 2022.07.13
Requires:       gap-transgrp >= 3.6.5
Requires:       gap-ugaly >= 4.1.3
Requires:       gap-unipot >= 1.6
Requires:       gap-unitlib >= 4.2.0
Requires:       gap-utils >= 0.85
Requires:       gap-uuid >= 0.7
Requires:       gap-walrus >= 0.9991
Requires:       gap-wedderga >= 4.10.5
Requires:       gap-wpe >= 0.8
Requires:       gap-xgap >= 4.32
Requires:       gap-xmod >= 2.92
Requires:       gap-xmodalg >= 1.23
Requires:       gap-yangbaxter >= 0.10.6
Requires:       gap-zeromqinterface >= 0.16

%description full
GAP is a system for computational discrete algebra, with particular
emphasis on Computational Group Theory.

This subpackage will pull in all optional packages of the GAP distribution.

%prep
%autosetup
echo "This package causes installation of optional GAP packages" >FULL.txt

%build
%configure
%make_build GAP_BUILD_DATETIME=""

%install
# Can not use "install" target, as that includes the "install-doc" target
make DESTDIR="%buildroot" INSTALL="install -p" \
  install-bin install-gaproot install-sysinfo install-headers install-libgap

# Fixup
rm -fv "%buildroot/%_libdir"/*.la
chmod +x %buildroot/%_datadir/gap%_sysconfdir/convert.pl

# For ancient modules
ln -s "%_bindir/gac" "%buildroot/%_libdir/gap/gac"

# openSUSE-specific extras for RPMs
install -D -m 0644 -t "%buildroot/%_prefix/lib/rpm/macros.d/" "%_sourcedir/macros.gap"
cat >> "%buildroot/%_prefix/lib/rpm/macros.d/macros.gapdirs" <<-EOF
	# Directory for modules extending the core
	%%gap_sitelib %gap_sitelib
	%%gap_sitearch %gap_sitearch
	%%gap_sitelib_anchor %_datadir
	%%gap_sitearch_anchor %_libdir
	%%gapdir %_libdir/gap
EOF
%fdupes %buildroot/%_includedir

%ldconfig_scriptlets -n %lname

%files
%_bindir/gap*
%dir %_libdir/gap/
%_libdir/gap/gap
%_datadir/gap/

%files -n %lname
%_libdir/libgap.so.9*

%files devel
%_bindir/gac*
%_includedir/gap/
%_libdir/pkgconfig/*.pc
%_libdir/libgap.so
%dir %_libdir/gap
%_libdir/gap/gac
%_libdir/gap/sysinfo.gap*

%files full
%doc FULL.txt

%files rpm-devel
%_prefix/lib/rpm/

%changelog
* Sun Feb  9 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.14
  * Added `NaturalGModule` for obtaining the natural module of a
    matrix group.
  * Added new function `MeetBlist`.
  * Added `PathSystemProgram`, the now recommended function to
    fetch the filename of a system program.
* Sat Mar 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.13
  * Change gac to respect CC and CXX environment variables if set
    (to override the C/C++ compiler it invokes)
  * Support package extensions (see the manual section
    "Extensions Provided by a Package")
  * Use gap-anupq package for computing isomorphism of p-groups
    if it is available
  * Speed up ``AsList``, ``AsSet`` and ``ElementsStabChain`` for
    permutation groups, by not sorting the list returned by
    ``ElementsStabChain`` (in accordance with its documentation,
    which never promised this)
* Wed Jan 31 2024 Jan Engelhardt <jengelh@inai.de>
- Make the build reproducible by killing off dates.
* Fri Jan 19 2024 Jan Engelhardt <jengelh@inai.de>
- Add sl2reps extension to gap-full
* Sun Feb 12 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.12.2
  * Fix an unexpected error during tab completion with records
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.12.1
  * Fix performance regression in AllHomomorphismClasses and
    possibly other code searching isomorphisms
  * Fix crashes in ConvertToVectorRep and CopyToVectorRep
* Sun Oct  2 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to new upstream release 4.12.0
  * Added the missing perfect groups of order up to two million
  * Initial support for make install available
  * For details, see
    https://github.com/gap-system/gap/blob/stable-4.12/CHANGES.md
- Update to new upstream release 4.11.0
  * Removed ability to return objects from many error break loops
  * GAP now contains some C++ code
  * HPC-GAP: The ward tool has been decommissioned
  * Syntax trees: Functions were added which allow converting a
    GAP function object into an abstract syntax tree which can
    be parsed and modified from within GAP code
- Clean up spec file
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.10.0
  * Reduce impact of immediate methods
  * Change definition of IsPGroup to not require finiteness
  * Experimental support for using the Julia garbage collector
  * For details, see
    https://www.gap-system.org/Manuals/doc/changes/chap2.html#X795B238486D0ABCD
* Fri Oct 19 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 4.9.3
  * Fixed a regression in HighestWeightModule caused by changes in
    sort functions introduced in GAP 4.9 release.
* Sat Jul 14 2018 jengelh@inai.de
- Update to new upstream release 4.9.2
  * Merged HPC-GAP into GAP.
  * GAP now supports lambdas with fewer or more than one argument.
  * Function calls, list accesses and records accesses now can be
    nested.
- Remove gap-final-dir.diff, gap-multiarch.diff, reproducible.patch
  (no longer needed).
* Tue Feb  6 2018 jengelh@inai.de
- Update to new upstream release 4.8.10
  * No changes to the GAP core.
  * Bundled modules in the GAP distribution were updated.
    (For openSUSE, this means an update happens in the separate
    gap-* packages.)
* Fri Jan 26 2018 bwiedemann@suse.com
- Add reproducible.patch to not include build time (boo#1047218)
- Drop config.log that differed for each build
* Mon Dec 25 2017 jengelh@inai.de
- Update to new upstream release 4.8.9
  * Fixed a bug in RepresentativeAction producing incorrect
    answers for both symmetric and alternating groups, with both
    OnTuples and OnSets, by producing elements outside the group.
  * Fixed a bug in RepresentativeAction for S_n and A_n acting on
    non-standard domains.
* Wed Sep 20 2017 jengelh@inai.de
- Update macros.gap to classify well-known license text files
  as %%doc.
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 4.8.8
  * Fixed a bug in RepresentativeAction producing incorrect
    answers for both symmetric and alternating groups, with both
    OnTuples and OnSets, by producing elements outside the group.
  * Fixed a bug in RepresentativeAction for S_n and A_n acting on
    non-standard domains.
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 4.8.7
  * Fixed a regression from GAP 4.7.6 when reading compressed files
    after a workspace is loaded. Before the fix, if GAP is started
    with the -L option (load workspace), using ReadLine on the
    input stream for a compressed file returned by InputTextFile
    only returned the first character.
* Mon Nov 21 2016 badshah400@gmail.com
- Update to version 4.8.6:
  * Fixed regression in the GAP kernel code introduced in GAP
    4.8.5 and breaking StringFile (GAPDoc: StringFile) ability to
    work with compressed files.
- Add an unpackaged file to filelist; fixes build failures.
* Sun Oct 16 2016 jengelh@inai.de
- Update to new upstream release 4.8.5
* Sun Mar 27 2016 jengelh@inai.de
- Update to new upstream release 4.8.3
  * No documentation available
* Sat Mar 12 2016 jengelh@inai.de
- Update to new upstream release 4.8.2
  * Added support for partially variadic functions to allow function
  expressions
  * GAP now displays the filename and line numbers of statements in
  backtraces when entering the break loop.
  * Developments from HPC-GAP were backported; "atomic", "readonly"
  and "readwrite" are now keywords, and thus are no longer valid
  identifiers.
- Remove gap-ttyname-null.diff (fixed upstream)
* Mon Dec  7 2015 jengelh@inai.de
- Update to new upstream release 4.7.9
* Mon Oct 12 2015 jengelh@inai.de
- Update to new upstream release 4.7.8
* Sun Feb 22 2015 jengelh@inai.de
- Update to new upstream release 4.7.7
  * Introduced some arithmetic operations for infinity and negative
  infinity.
  * Introduced new property IsGeneratorsOfSemigroup which reflects
  whether the list or collection generates a semigroup.
* Wed Jun 18 2014 jengelh@inai.de
- Update to new upstream release 4.7.5
  * InstallValue cannot handle immediate values, characters or
  booleans for technical reasons. A check for such values was
  introduced to trigger an error message and prevent incorrect
  results caused by this.
  * KnowsDictionary and LookupDictionary methods for
  IsListLookupDictionary were using PositionFirstComponent; the
  latter is only valid on sorted lists, but in
  IsListLookupDictionary the underlying list is NOT sorted in
  general, leading to bogus results.
* Fri Apr 18 2014 jengelh@inai.de
- Update to new upstream release 4.7.4
  * Incorrect result returned by AutomorphismGroup(PSp(4,2^n)) was
  fixed.
  * The "Order" method for group homomorphisms newly introduced in
  GAP 4.7 had a bug that caused it to sometimes return incorrect
  results, which was fixed.
  * Break loop in IsomorphismFpMonoid when prefixes in generators
  names were longer than one letter.
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 4.7.2
  * The methods for computing conjugacy classes of permutation
  groups have been rewritten from scratch to enable potential use
  for groups in different representations.
  * The methods for determining (conjugacy classes of) subgroups in
  non-solvable groups have been substantially improved in speed
  and scope for groups with multiple nonabelian composition
  factors.
  * There is a new method for calculating the maximal subgroups of
  a permutation group (with chief factors of width less or equal
  5) without calculating the whole subgroup lattice.
  * The functionality in GAP for transformations and transformation
  semigroups has been rewritten and extended. Partial
  permutations and inverse semigroups have been newly
  implemented. The documentation for transformations and
  transformation semigroups has been improved. Transformations
  and partial permutations are implemented in the GAP kernel.
  Methods for calculating attributes of transformations and
  partial permutations, and taking products, and so are also
  implemented in the kernel.
* Fri May 10 2013 jengelh@inai.de
- Update to new upstream release 4.6.4
- Split .spec file into multiple packages
- Add gap-final-dir.diff, gap-multiarch.diff
* Thu Nov 29 2012 jengelh@inai.de
- Avoid fdupes in /etc
* Fri Aug 31 2012 scorot@free.fr
- add --target to configure for SLE 11 i586
* Fri Aug 31 2012 scorot@free.fr
- add libtool in build requirements for 12.2
* Sat Jul  7 2012 scorot@free.fr
- fix build on SLE 11
- spec file reformating
* Sun Jun 26 2011 jengelh@medozas.de
- Add gap-typepuns.diff
